Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(690)

Unified Diff: media/base/audio_renderer_sink.h

Issue 2517503003: Reland: Make more media APIs aware of |delay| and |delay_timestamp| (Closed)
Patch Set: Comments from chcunningham@ and Dale Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/audio_renderer_mixer_unittest.cc ('k') | media/base/fake_audio_render_callback.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/audio_renderer_sink.h
diff --git a/media/base/audio_renderer_sink.h b/media/base/audio_renderer_sink.h
index f768b7cb1b42d2f0fbb4d7f192b2df5a1d7840ab..4052112bab555b6703c90962422323f5cbeff0e4 100644
--- a/media/base/audio_renderer_sink.h
+++ b/media/base/audio_renderer_sink.h
@@ -28,14 +28,15 @@ class AudioRendererSink
class RenderCallback {
public:
// Attempts to completely fill all channels of |dest|, returns actual
// number of frames filled. |frames_skipped| contains the number of frames
// the consumer has skipped, if any.
- // TODO(jameswest): Change to use the same signature as
- // AudioOutputStream::AudioSourceCallback::OnMoreData.
- virtual int Render(AudioBus* dest,
- uint32_t frames_delayed,
- uint32_t frames_skipped) = 0;
-
+ // The |delay| argument represents audio device output latency,
+ // |delay_timestamp| represents the time when |delay| was obtained.
+ virtual int Render(base::TimeDelta delay,
+ base::TimeTicks delay_timestamp,
+ int prior_frames_skipped,
+ AudioBus* dest) = 0;
// Signals an error has occurred.
virtual void OnRenderError() = 0;
« no previous file with comments | « media/base/audio_renderer_mixer_unittest.cc ('k') | media/base/fake_audio_render_callback.h » ('j') | no next file with comments »
@@ -28,14 +28,15 @@ class AudioRendererSink
public:
// Attempts to completely fill all channels of |dest|, returns actual
- // number of frames filled. |frames_skipped| contains the number of frames
+ // number of frames filled. |prior_frames_skipped| contains the number of
+ // frames
// the consumer has skipped, if any.

Powered by Google App Engine
This is Rietveld 408576698